==> bow-ui-0.5-sources.jar: org/chorem/bow/BowMail.java <==
/*
 * #%L
 * bow
 * 
 * $Id: BowMail.java 192 2011-02-14 14:53:06Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-0.5/bow-ui/src/main/java/org/chorem/bow/BowMail.java $
 * %%
 * Copyright (C) 2010 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow;

import java.util.Properties;

import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;

public class BowMail {
    static public void sendMail(String sendToEmail, String mailSubject, String mailContent) throws AddressException, MessagingException {
	BowConfig config = BowConfig.getInstance();
	String smtpServer = config.getSmtpServer();
	Properties properties = new Properties();
	properties.put("mail.smtp.host", smtpServer);
	
	Session session = Session.getDefaultInstance(properties, null);
	session.setDebug(true);
	
	Message msg = new MimeMessage(session);
	
	msg.addRecipient(Message.RecipientType.TO, new InternetAddress(sendToEmail));
	msg.setFrom(new InternetAddress(config.getAddressFrom()));
	msg.setSubject(mailSubject);
	msg.setContent(mailContent, "text/plain");
	Transport.send(msg);
    }
}

==> bow-ui-1.0-sources.jar: org/chorem/bow/BowMail.java <==
/*
 * #%L
 * bow
 * 
 * $Id: BowMail.java 285 2011-05-16 13:21:52Z sletellier $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-1.0/bow-ui/src/main/java/org/chorem/bow/BowMail.java $
 * %%
 * Copyright (C) 2010 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow;

import org.nuiton.util.ApplicationConfig;

import java.util.Properties;

import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;

public class BowMail {

    static public void sendMail(String sendToEmail, String mailSubject, String mailContent) throws AddressException, MessagingException {
        String smtpServer = BowConfig.getSmtpServer();
        Properties properties = new Properties();
        properties.put("mail.smtp.host", smtpServer);

        Session session = Session.getDefaultInstance(properties, null);
        session.setDebug(true);

        Message msg = new MimeMessage(session);

        msg.addRecipient(Message.RecipientType.TO, new InternetAddress(sendToEmail));
        msg.setFrom(new InternetAddress(BowConfig.getAddressFrom()));
        msg.setSubject(mailSubject);
        msg.setContent(mailContent, "text/plain");
        Transport.send(msg);
    }
}
